(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     61313,       1589]
NotebookOptionsPosition[     58786,       1545]
NotebookOutlinePosition[     59144,       1561]
CellTagsIndexPosition[     59101,       1558]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["By Joshua R. Davis, jdavis@carleton.edu", "Text",
 CellChangeTimes->{{3.731427728182392*^9, 
  3.731427734778235*^9}},ExpressionUUID->"110428d9-9d44-43c0-8541-\
740ba33aef00"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.731427724480824*^9, 
  3.731427725756515*^9}},ExpressionUUID->"4a6ded8e-c170-428e-ad00-\
71feadc4ac30"],

Cell["\<\
Structural geology is the study of how rocks deform --- fracture, fold, etc. \
Observing, describing, and modeling how rocks deform can help us understand \
basic scientific questions, for example about plate tectonics. It can also \
affect our solutions to practical problems such as assessing earthquake \
hazards, designing dams, and, um, finding petroleum.

Linear transformations, as represented by matrices, provide a simple \
mathematical framework for quantifying rock deformation. This notebook shows \
some animated examples. I hope that it helps you develop a visual \
understanding of how matrices work. (Of course, you should also develop your \
formal, symbolic understanding.)\
\>", "Text",
 CellChangeTimes->{{3.731427587448619*^9, 3.731427698763682*^9}, {
  3.731427762898576*^9, 
  3.73142796735295*^9}},ExpressionUUID->"bcbdea87-1a3e-419a-8adb-\
3285c878fe1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Infrastructure", "Section",
 CellChangeTimes->{{3.731420224782115*^9, 
  3.73142022704275*^9}},ExpressionUUID->"0a6e9ec8-c917-4590-8734-\
7f19f36a8c03"],

Cell["\<\
Run this huge cell of code, but don\[CloseCurlyQuote]t worry about how it \
works. (To run a cell, click anywhere in the cell, and press Shift-Enter.)\
\>", "Text",
 CellChangeTimes->{{3.731420758962742*^9, 3.731420766577146*^9}, {
  3.7314279718694487`*^9, 
  3.731427994084938*^9}},ExpressionUUID->"d1b0d43d-ddb4-44c7-8ea6-\
383060a6d197"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"deformedCurvesPoints", ",", " ", "deformer"}], "]"}], ";"}], 
  "\n", 
  RowBox[{"(*", " ", 
   RowBox[{"Helper", " ", "function", " ", "for", " ", 
    RowBox[{"deformer", "."}]}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"deformedCurvesPoints", "[", 
     RowBox[{
     "bound_", ",", " ", "curves_", ",", " ", "points_", ",", " ", 
      "matrix_"}], "]"}], " ", ":=", "\n", "\t", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "objects", "}"}], ",", "\n", "\t\t", 
      RowBox[{
       RowBox[{"objects", " ", "=", " ", 
        RowBox[{"{", "\n", "\t\t\t", 
         RowBox[{
          RowBox[{"RGBColor", "[", 
           RowBox[{"0.0", ",", " ", "0.0", ",", " ", "0.0"}], "]"}], ",", 
          "\n", "\t\t\t", 
          RowBox[{"PointSize", "[", "Large", "]"}], ",", "\n", "\t\t\t", 
          RowBox[{"Point", "[", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{"Function", "[", 
              RowBox[{"point", ",", " ", 
               RowBox[{"Chop", "[", 
                RowBox[{"point", ".", 
                 RowBox[{"Transpose", "[", "matrix", "]"}]}], "]"}]}], "]"}], 
             ",", " ", "points"}], "]"}], "]"}], ",", "\n", "\t\t\t", 
          RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", "\n", "\t\t\t", 
          RowBox[{"Line", "[", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{"Function", "[", 
              RowBox[{"curve", ",", " ", 
               RowBox[{"Chop", "[", 
                RowBox[{"curve", ".", 
                 RowBox[{"Transpose", "[", "matrix", "]"}]}], "]"}]}], "]"}], 
             ",", " ", "curves"}], "]"}], "]"}]}], "}"}]}], ";", "\n", "\t\t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "matrix", "]"}], " ", "==", " ", "2"}], ",", 
         "\n", "\t\t\t", 
         RowBox[{"Graphics", "[", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "\n", "\t\t\t\t", 
             RowBox[{
              RowBox[{"RGBColor", "[", 
               RowBox[{"1.0", ",", " ", "0.0", ",", " ", "0.0"}], "]"}], ",", 
              "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"bound", ",", " ", "0"}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}], "]"}], ",", 
              "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "bound"}], ",", " ", "0"}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "bound"}], "/", "2"}], ",", " ", "0"}], 
                  "}"}]}], "}"}], "]"}], ",", "\n", "\t\t\t\t", 
              RowBox[{"RGBColor", "[", 
               RowBox[{"0.0", ",", " ", "1.0", ",", " ", "0.0"}], "]"}], ",", 
              "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "bound"}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}], "]"}], ",", 
              "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", 
                   RowBox[{"-", "bound"}]}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", 
                   RowBox[{
                    RowBox[{"-", "bound"}], "/", "2"}]}], "}"}]}], "}"}], 
               "]"}]}], "}"}], ",", "\n", "\t\t\t\t", "objects"}], "]"}], 
          "]"}], ",", "\n", "\t\t\t", 
         RowBox[{"Graphics3D", "[", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "\n", "\t\t\t\t", 
             RowBox[{
              RowBox[{"RGBColor", "[", 
               RowBox[{"1.0", ",", " ", "0.0", ",", " ", "0.0"}], "]"}], ",", 
              "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"bound", ",", " ", "0", ",", " ", "0"}], "}"}], ",",
                  " ", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], "}"}],
                "]"}], ",", "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "bound"}], ",", " ", "0", ",", " ", "0"}], 
                  "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "bound"}], "/", "2"}], ",", " ", "0", ",", 
                   " ", "0"}], "}"}]}], "}"}], "]"}], ",", "\n", "\t\t\t\t", 
              RowBox[{"RGBColor", "[", 
               RowBox[{"0.0", ",", " ", "1.0", ",", " ", "0.0"}], "]"}], ",", 
              "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "bound", ",", " ", "0"}], "}"}], ",",
                  " ", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], "}"}],
                "]"}], ",", "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", 
                   RowBox[{"-", "bound"}], ",", " ", "0"}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", 
                   RowBox[{
                    RowBox[{"-", "bound"}], "/", "2"}], ",", " ", "0"}], 
                  "}"}]}], "}"}], "]"}], ",", "\n", "\t\t\t\t", 
              RowBox[{"RGBColor", "[", 
               RowBox[{"0.0", ",", " ", "0.0", ",", " ", "1.0"}], "]"}], ",", 
              "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "0", ",", " ", "bound"}], "}"}], ",",
                  " ", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], "}"}],
                "]"}], ",", "\n", "\t\t\t\t", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "0", ",", " ", 
                   RowBox[{"-", "bound"}]}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", " ", "0", ",", " ", 
                   RowBox[{
                    RowBox[{"-", "bound"}], "/", "2"}]}], "}"}]}], "}"}], 
               "]"}]}], "}"}], ",", "\n", "\t\t\t\t", "objects"}], "]"}], 
          "]"}]}], "]"}]}]}], "]"}]}], ";"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Returns", " ", "a", " ", "manipulator", " ", "for", " ", "a", " ", "2", 
    "D", " ", "or", " ", "3", "D", " ", 
    RowBox[{"deformation", "."}]}], " ", "*)"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "bound", " ", "determines", " ", "the", " ", "length", " ", "of", " ", 
    "the", " ", "coordinate", " ", "axes", " ", "and", " ", "often", " ", 
    "the", " ", 
    RowBox[{"view", "."}]}], " ", "*)"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "curves", " ", "and", " ", "points", " ", "are", " ", "some", " ", 
    "curves", " ", "and", " ", "points", " ", "to", " ", "be", " ", 
    RowBox[{"deformed", "."}]}], " ", "*)"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"matrix", " ", "is", " ", "a", " ", "t"}], "-", 
    RowBox[{
    "dependent", " ", "matrix", " ", "used", " ", "to", " ", "deform", " ", 
     "the", " ", "curves", " ", "and", " ", 
     RowBox[{"points", "."}]}]}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"deformer", "[", 
    RowBox[{
    "bound_", ",", " ", "curves_", ",", " ", "points_", ",", " ", "matrix_"}],
     "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"deformedCurvesPoints", "[", 
      RowBox[{
      "bound", ",", " ", "curves", ",", " ", "points", ",", " ", "matrix"}], 
      "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"box2D", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", " ", 
         RowBox[{"-", "1"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", 
         RowBox[{"-", "1"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1"}], "}"}]}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"circlePoints", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", " ", "b_"}], "}"}], ",", " ", "r_", ",", " ", "n_"}],
     "]"}], " ", ":=", " ", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], " ", "+", " ", "a"}], ",", " ", 
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], " ", "+", " ", "b"}]}], "}"}], ",",
      " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", 
       RowBox[{"2", " ", "Pi"}], ",", " ", 
       RowBox[{"2", " ", 
        RowBox[{"Pi", " ", "/", " ", "n"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"circle2D", " ", "=", " ", 
   RowBox[{"circlePoints", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", "1", ",", " ", "100"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rock2D", " ", "=", " ", 
   RowBox[{"Append", "[", 
    RowBox[{"box2D", ",", " ", "circle2D"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"box3D", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.529348684187306*^9, 3.529348781979908*^9}, {
   3.529349118465267*^9, 3.529349123419303*^9}, {3.599910691573656*^9, 
   3.599910699867443*^9}, {3.600105855127783*^9, 3.600105968962596*^9}, {
   3.731420216808578*^9, 3.731420220398046*^9}, 
   3.731428002084297*^9},ExpressionUUID->"5c427fc6-9b24-4ccb-a382-\
3de6aab81682"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Section",
 CellChangeTimes->{{3.731420245376864*^9, 
  3.731420267566079*^9}},ExpressionUUID->"618be81e-2e1d-4c69-9542-\
8895c509a573"],

Cell["\<\
2D simple shearing. This is a simple model for what happens to rock between \
two tectonic plates that are grinding past each other (such as the Pacific \
and North America, along the San Andreas fault). Run it and play with the \
slider. Change gamma and re-run the cell, to explore the meaning of gamma.\
\>", "Text",
 CellChangeTimes->{{3.731420333355103*^9, 3.731420335163609*^9}, {
  3.731420369715074*^9, 3.731420394493075*^9}, {3.731428261815466*^9, 
  3.7314282631199703`*^9}, {3.731429777210681*^9, 3.731429807156879*^9}, {
  3.731429884013139*^9, 
  3.731429919172112*^9}},ExpressionUUID->"3c8bd183-6627-4c4e-9caf-\
ece6f5e777e7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gamma", " ", "=", " ", "1.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vgt", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "gamma"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"MatrixExp", "[", "vgt", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"deformer", "[", 
  RowBox[{"3", ",", " ", "rock2D", ",", " ", 
   RowBox[{"{", "}"}], ",", " ", 
   RowBox[{"MatrixExp", "[", 
    RowBox[{"t", " ", "vgt"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.731420262290162*^9, 3.73142031025185*^9}, {
   3.7314204160591097`*^9, 3.731420416286043*^9}, {3.731420608808675*^9, 
   3.7314206191780233`*^9}, {3.7314206604948387`*^9, 3.731420661466799*^9}, 
   3.731420859773712*^9, {3.731425973538909*^9, 3.73142597697865*^9}, {
   3.731428915502556*^9, 
   3.731428917421299*^9}},ExpressionUUID->"ca00027d-27bd-4f01-99ec-\
4f53ef1f926b"],

Cell["\<\
2D pure shearing. This is a simple model for what happens to rock between two \
tectonic plates that are ramming into each other (such as India and Asia). \
Change log(k) to explore its meaning.\
\>", "Text",
 CellChangeTimes->{{3.731420380142227*^9, 3.731420388507762*^9}, {
  3.731420426328508*^9, 3.731420427571253*^9}, {3.731420523042841*^9, 
  3.731420527367969*^9}, {3.73142826943117*^9, 3.7314282702979937`*^9}, {
  3.731428668448884*^9, 3.731428691363284*^9}, {3.731429737773201*^9, 
  3.731429758516308*^9}, {3.731429882312008*^9, 
  3.731429906966164*^9}},ExpressionUUID->"578e0f6e-2f49-440b-a655-\
521fda441a9f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"logK", " ", "=", " ", "1.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vgt", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"logK", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"-", "logK"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"MatrixExp", "[", "vgt", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"deformer", "[", 
  RowBox[{"3", ",", " ", "rock2D", ",", " ", 
   RowBox[{"{", "}"}], ",", " ", 
   RowBox[{"MatrixExp", "[", 
    RowBox[{"t", " ", "vgt"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.731420408086975*^9, 3.731420459366303*^9}, {
  3.731420560535763*^9, 3.731420589235064*^9}, {3.731420668563615*^9, 
  3.731420669450488*^9}, {3.7314208484609137`*^9, 
  3.731420850018099*^9}},ExpressionUUID->"b5ce6e03-aae2-437c-88fd-\
1b47cd4796d9"],

Cell["\<\
2D pure rotation. In itself, this is not especially geologically relevant. \
But all 2D deformations can be viewed as a mixture of rotation and pure \
shearing (above). And it\[CloseCurlyQuote]s instructive for linear algebra \
students. Change theta to explore.\
\>", "Text",
 CellChangeTimes->{{3.731420471749939*^9, 3.7314204772499037`*^9}, {
  3.731428266266968*^9, 3.731428267271944*^9}, {3.731429820601264*^9, 
  3.731429864453621*^9}, {3.731429939132608*^9, 
  3.7314299666065693`*^9}},ExpressionUUID->"afcc0997-b1b3-4cea-98d8-\
bc44f3799d72"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"theta", " ", "=", " ", 
   RowBox[{"Pi", " ", "/", " ", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vgt", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"-", "theta"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"theta", ",", " ", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"MatrixExp", "[", "vgt", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"deformer", "[", 
  RowBox[{"3", ",", " ", "rock2D", ",", " ", 
   RowBox[{"{", "}"}], ",", " ", 
   RowBox[{"MatrixExp", "[", 
    RowBox[{"t", " ", "vgt"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.73142049026171*^9, 3.731420505967197*^9}, {
   3.731420605098013*^9, 3.731420629521701*^9}, {3.731420664779895*^9, 
   3.731420665630563*^9}, 
   3.7314208576552896`*^9},ExpressionUUID->"00300c81-3e6e-43be-839f-\
5a3664d2a8b7"],

Cell["\<\
Here are some 3D examples. Steady coaxial deformation, and steady coaxial \
deformation with extraneous rotation. They have the same finite effect (the \
difference between the start and end), but they interpolate differently. The \
interpolation is not really a topic for linear algebra, so maybe you should \
forget that I brought it up.\
\>", "Text",
 CellChangeTimes->{{3.429021495920505*^9, 3.429021508924234*^9}, {
   3.47810881393962*^9, 3.478108823928383*^9}, {3.491764797006815*^9, 
   3.491764800069796*^9}, {3.5869410892264147`*^9, 3.586941093217491*^9}, 
   3.731420345769904*^9, {3.731428045035699*^9, 3.731428095245718*^9}, {
   3.7314282505033903`*^9, 3.7314282548756857`*^9}, {3.7314287143628902`*^9, 
   3.73142873739296*^9}},ExpressionUUID->"7fc55463-b935-4f26-aec3-\
0ba53d41a278"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vgt", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", "1.5", "]"}]}], ",", " ", "0", ",", " ", "0"}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"-", 
        RowBox[{"Log", "[", "1.5", "]"}]}], ",", " ", "0"}], "}"}], ",", " ", 
     
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", 
       RowBox[{"Log", "[", "2.25", "]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"MatrixExp", "[", "vgt", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"deformer", "[", 
  RowBox[{"3", ",", " ", "box3D", ",", " ", 
   RowBox[{"{", "}"}], ",", " ", 
   RowBox[{"MatrixExp", "[", 
    RowBox[{"t", " ", "vgt"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vgt", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Log", "[", "1.5", "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "Pi", " ", "k"}], ",", " ", "0"}], "}"}], 
      ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"2", " ", "Pi", " ", "k"}], ",", " ", 
        RowBox[{"-", 
         RowBox[{"Log", "[", "1.5", "]"}]}], ",", " ", "0"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "0", ",", " ", 
        RowBox[{"Log", "[", "2.25", "]"}]}], "}"}]}], "}"}], " ", "/.", " ", 
    RowBox[{"k", " ", "\[Rule]", " ", "1"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"MatrixExp", "[", "vgt", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"deformer", "[", 
  RowBox[{"3", ",", " ", "box3D", ",", " ", 
   RowBox[{"{", "}"}], ",", " ", 
   RowBox[{"MatrixExp", "[", 
    RowBox[{"t", " ", "vgt"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.428809124876296*^9, 3.428809160047433*^9}, {
  3.429021205202964*^9, 3.4290212638604107`*^9}, {3.4290213138894243`*^9, 
  3.4290213756647587`*^9}, {3.429021431507162*^9, 3.4290214654748383`*^9}, {
  3.478102359830145*^9, 3.47810240894031*^9}, {3.4781024493221893`*^9, 
  3.4781024922528257`*^9}, {3.5103964019013853`*^9, 3.5103964100506907`*^9}, {
  3.530811816065645*^9, 3.530811828560408*^9}, {3.731420675672626*^9, 
  3.7314207270854607`*^9}},ExpressionUUID->"604ea736-7ca2-4a22-a370-\
22bd56bc696e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More infrastructure", "Section",
 CellChangeTimes->{{3.5690799283219767`*^9, 3.569079935104415*^9}, {
  3.7314273983237753`*^9, 
  3.731427400465542*^9}},ExpressionUUID->"2b02ec06-cc8c-49f5-80a7-\
7d9f4c29b31d"],

Cell["\<\
Now we build up some more complicated infrastructure for more complicated \
visualizations. Run this giant cell, without worrying about how it works.\
\>", "Text",
 CellChangeTimes->{{3.731428104063595*^9, 3.731428123728881*^9}, {
  3.7314282871182623`*^9, 3.73142829306875*^9}, {3.73142874930549*^9, 
  3.731428749958417*^9}},ExpressionUUID->"6f45deab-f065-47cd-9dbe-\
8a7f19794cb6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "layerCurve", ",", " ", "zoneCurves", ",", " ", "curvesGraphic", ",", " ", 
    "translation", ",", " ", "scaling", ",", " ", "deformation", ",", 
    "isError", ",", " ", "passError", ",", " ", "euclideanRungeKutta", ",", 
    " ", "flow"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cubeCurves", " ", "=", " ", "\n", "\t", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "1", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], "}"}], ",", 
     "\n", "\t", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1", ",", " ", "1"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "1", ",", " ", "1"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "}"}], ",", 
     "\n", "\t", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "0", ",", " ", "1"}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1", ",", " ", "1"}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "1", ",", " ", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "1", ",", " ", "1"}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"layerCurve", "[", "numSamples_", "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Join", "[", "\n", "\t\t", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], "}"}], ",", "\n", 
     "\t\t", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", " ", 
         RowBox[{"s", " ", "/", " ", "numSamples"}], ",", " ", "0"}], "}"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"s", ",", " ", "0", ",", " ", "numSamples"}], "}"}]}], "]"}], 
     ",", "\n", "\t\t", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"s", " ", "/", " ", "numSamples"}]}], ",", " ", "0"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"s", ",", " ", "0", ",", " ", "numSamples"}], "}"}]}], 
      "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"zoneCurves", "[", 
    RowBox[{"numLayers_", ",", " ", "numSamples_"}], "]"}], " ", ":=", "\n", 
   "\t", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "layer", "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{"layer", " ", "=", " ", 
       RowBox[{"layerCurve", "[", "numSamples", "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"Join", "[", "\n", "\t\t\t", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "}"}], ",",
           " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"1", ",", " ", "0", ",", " ", "1"}], "}"}]}], "}"}], ",",
           " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "1", ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "1", ",", " ", "1"}], "}"}]}], "}"}], ",",
           " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", " ", "1", ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"1", ",", " ", "1", ",", " ", "1"}], "}"}]}], "}"}]}], 
         "}"}], ",", "\n", "\t\t\t", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"translation", "[", 
             RowBox[{
              RowBox[{"{", "layer", "}"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"0", ",", " ", "0", ",", " ", 
                RowBox[{"l", " ", "/", " ", "numLayers"}]}], "}"}]}], "]"}], 
            ",", " ", 
            RowBox[{"{", 
             RowBox[{"l", ",", " ", "0", ",", " ", "numLayers"}], "}"}]}], 
           "]"}], ",", " ", "1"}], "]"}]}], "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"curvesGraphic", "[", "curves_", "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"Thickness", "[", "Large", "]"}], ",", "\n", "\t\t\t", "Red",
          ",", " ", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"0.5", ",", " ", "0", ",", " ", "0"}], "}"}]}], "}"}], 
          "]"}], ",", "\n", "\t\t\t", "Green", ",", " ", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "0.5", ",", " ", "0"}], "}"}]}], "}"}], 
          "]"}], ",", "\n", "\t\t\t", "Blue", ",", " ", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"0", ",", " ", "0", ",", " ", "0.5"}], "}"}]}], "}"}], 
          "]"}], ",", "\n", "\t\t\t", 
         RowBox[{"Thickness", "[", "Small", "]"}], ",", "\n", "\t\t\t", 
         "Black"}], "}"}], ",", "\n", "\t\t", 
       RowBox[{"Map", "[", 
        RowBox[{"Line", ",", " ", "curves"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"translation", "[", 
    RowBox[{"curves_", ",", " ", "d_"}], "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{"Function", "[", 
      RowBox[{"point", ",", " ", 
       RowBox[{"point", " ", "+", " ", "d"}]}], "]"}], ",", " ", "curves", 
     ",", " ", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"scaling", "[", 
    RowBox[{"curves_", ",", " ", "abc_"}], "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{"Function", "[", 
      RowBox[{"point", ",", " ", 
       RowBox[{"abc", " ", "point"}]}], "]"}], ",", " ", "curves", ",", " ", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"deformation", "[", 
    RowBox[{"curves_", ",", " ", "f_"}], "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{"Function", "[", 
      RowBox[{"point", ",", " ", 
       RowBox[{"f", ".", "point"}]}], "]"}], ",", " ", "curves", ",", " ", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"isError", "[", "value_", "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"And", "[", 
    RowBox[{
     RowBox[{"ListQ", "[", "value", "]"}], ",", " ", 
     RowBox[{"StringQ", "[", 
      RowBox[{"value", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"passError", "[", 
    RowBox[{"function_", ",", " ", "arguments_", ",", " ", "header_"}], "]"}],
    " ", ":=", "\n", "\t", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "value", "}"}], ",", " ", 
     RowBox[{
      RowBox[{"value", " ", "=", " ", 
       RowBox[{"Catch", "[", 
        RowBox[{"Quiet", "[", 
         RowBox[{"Check", "[", 
          RowBox[{
           RowBox[{"Apply", "[", 
            RowBox[{"function", ",", " ", "arguments"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<message:\>\"", ",", " ", "function", ",", " ", "arguments"}],
             "}"}]}], "]"}], "]"}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"isError", "[", "value", "]"}], ",", "\n", "\t\t\t", 
        RowBox[{"Throw", "[", 
         RowBox[{"Append", "[", 
          RowBox[{"header", ",", " ", "value"}], "]"}], "]"}], ",", "\n", 
        "\t\t\t", "value"}], "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"euclideanRungeKutta", "[", 
    RowBox[{
    "g_", ",", " ", "x_", ",", " ", "n_", ",", " ", "t0_", ",", " ", "t1_"}], 
    "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "h", ",", " ", "last", ",", " ", "t", ",", " ", "i", ",", " ", "k1", 
       ",", " ", "k2", ",", " ", "k3", ",", " ", "k4"}], "}"}], ",", "\n", 
     "\t\t", 
     RowBox[{
      RowBox[{"h", " ", "=", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t1", " ", "-", " ", "t0"}], ")"}], " ", "/", " ", "n"}]}], 
      ";", "\n", "\t\t", 
      RowBox[{"last", " ", "=", " ", "g"}], ";", "\n", "\t\t", 
      RowBox[{"t", " ", "=", " ", "t0"}], ";", "\n", "\t\t", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", " ", "=", " ", "0"}], ",", " ", 
        RowBox[{"i", " ", "<", " ", "n"}], ",", " ", 
        RowBox[{"i", " ", "+=", " ", "1"}], ",", "\n", "\t\t\t", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"Compute", " ", 
           RowBox[{"x", "[", "last", "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"etc", ".", " ", "in"}], " ", "a", " ", "way", " ", "that",
            " ", "lets", " ", "errors", " ", "be", " ", 
           RowBox[{"reported", "."}]}]}], " ", "*)"}], "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"k1", " ", "=", " ", 
          RowBox[{"passError", "[", 
           RowBox[{"x", ",", " ", 
            RowBox[{"{", 
             RowBox[{"t", ",", " ", "last"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{
             "\"\<euclideanRungeKutta: k1: g, n, i:\>\"", ",", " ", "g", ",", 
              " ", "n", ",", " ", "i"}], "}"}]}], "]"}]}], ";", "\n", 
         "\t\t\t", 
         RowBox[{"k2", " ", "=", " ", 
          RowBox[{"passError", "[", 
           RowBox[{"x", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"t", " ", "+", " ", 
               RowBox[{"0.5", " ", "h"}]}], ",", " ", 
              RowBox[{"last", " ", "+", " ", 
               RowBox[{"0.5", " ", "h", " ", "k1"}]}]}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{
             "\"\<euclideanRungeKutta: k2: g, n, i:\>\"", ",", " ", "g", ",", 
              " ", "n", ",", " ", "i"}], "}"}]}], "]"}]}], ";", "\n", 
         "\t\t\t", 
         RowBox[{"k3", " ", "=", " ", 
          RowBox[{"passError", "[", 
           RowBox[{"x", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"t", " ", "+", " ", 
               RowBox[{"0.5", " ", "h"}]}], ",", " ", 
              RowBox[{"last", " ", "+", " ", 
               RowBox[{"0.5", " ", "h", " ", "k2"}]}]}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{
             "\"\<euclideanRungeKutta: k3: g, n, i:\>\"", ",", " ", "g", ",", 
              " ", "n", ",", " ", "i"}], "}"}]}], "]"}]}], ";", "\n", 
         "\t\t\t", 
         RowBox[{"k4", " ", "=", " ", 
          RowBox[{"passError", "[", 
           RowBox[{"x", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"t", " ", "+", " ", "h"}], ",", " ", 
              RowBox[{"last", " ", "+", " ", 
               RowBox[{"h", " ", "k3"}]}]}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{
             "\"\<euclideanRungeKutta: k4: g, n, i:\>\"", ",", " ", "g", ",", 
              " ", "n", ",", " ", "i"}], "}"}]}], "]"}]}], ";", "\n", 
         "\t\t\t", 
         RowBox[{"last", " ", "+=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"h", " ", "/", " ", "6.0"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"k1", " ", "+", " ", 
             RowBox[{"2.0", " ", "k2"}], " ", "+", " ", 
             RowBox[{"2.0", " ", "k3"}], " ", "+", " ", "k4"}], ")"}]}]}], 
         ";", "\n", "\t\t\t", 
         RowBox[{"t", " ", "+=", " ", "h"}]}]}], "]"}], ";", "\n", "\t\t", 
      "last"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"flow", "[", 
    RowBox[{"curves_", ",", " ", "v_", ",", " ", "t1_"}], "]"}], " ", ":=", 
   "\n", "\t", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{"Function", "[", 
      RowBox[{"point", ",", " ", 
       RowBox[{"euclideanRungeKutta", "[", 
        RowBox[{
        "point", ",", " ", "v", ",", " ", "10", ",", " ", "0", ",", " ", 
         "t1"}], "]"}]}], "]"}], ",", " ", "curves", ",", " ", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "transpressionGraphicTF", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"transpressionGraphicTF", "[", 
    RowBox[{"h0_", ",", " ", "gamma_", ",", " ", "k_", ",", " ", "t_"}], 
    "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "zoneA", ",", " ", "zoneB", ",", " ", "blockA", ",", " ", "blockB", ",",
        " ", "f", ",", " ", "disp"}], "}"}], ",", "\n", "\t\t", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Set", " ", "up", " ", "the", " ", "geometry", " ", "at", " ", "time", 
       " ", "0."}], " ", "*)"}], "\n", "\t\t", 
     RowBox[{
      RowBox[{"zoneA", " ", "=", " ", 
       RowBox[{"scaling", "[", 
        RowBox[{
         RowBox[{"zoneCurves", "[", 
          RowBox[{"4", ",", " ", "4"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"2", ",", " ", "h0", ",", " ", "2"}], "}"}]}], "]"}]}], ";",
       "\n", "\t\t", 
      RowBox[{"zoneB", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"zoneA", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", " ", "0", ",", " ", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"zoneA", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"zoneA", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", " ", 
           RowBox[{"-", "h0"}], ",", " ", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"blockA", " ", "=", " ", 
       RowBox[{"scaling", "[", 
        RowBox[{"cubeCurves", ",", " ", 
         RowBox[{"{", 
          RowBox[{"2", ",", " ", "1", ",", " ", "2"}], "}"}]}], "]"}]}], ";", 
      "\n", "\t\t", 
      RowBox[{"blockB", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"blockA", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", " ", "h0", ",", " ", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"blockA", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"blockA", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", " ", 
           RowBox[{
            RowBox[{"-", "3"}], "h0"}], ",", " ", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Compute", " ", "the", " ", "block", " ", "displacement", " ", "at", 
        " ", "time", " ", 
        RowBox[{"t", "."}]}], " ", "*)"}], "\n", "\t\t", 
      RowBox[{"f", " ", "=", " ", 
       RowBox[{"MatrixExp", "[", 
        RowBox[{"t", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "gamma", ",", " ", "0"}], "}"}], ",", " ", 
           
           RowBox[{"{", 
            RowBox[{"0", ",", " ", 
             RowBox[{"Log", "[", "k", "]"}], ",", " ", "0"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0", ",", " ", 
             RowBox[{"-", 
              RowBox[{"Log", "[", "k", "]"}]}]}], "}"}]}], "}"}]}], "]"}]}], 
      ";", "\n", "\t\t", 
      RowBox[{"disp", " ", "=", " ", 
       RowBox[{
        RowBox[{"f", ".", 
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "h0", ",", " ", "0"}], "}"}]}], " ", "-", 
        " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "h0", ",", " ", "0"}], "}"}]}]}], ";", "\n", 
      "\t\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Compute", " ", "the", " ", "geometry", " ", "at", " ", "time", " ", 
        RowBox[{"t", "."}]}], " ", "*)"}], "\n", "\t\t", 
      RowBox[{"blockA", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"blockA", ",", " ", 
         RowBox[{"-", "disp"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"blockB", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"blockB", ",", " ", "disp"}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"zoneA", " ", "=", " ", 
       RowBox[{"deformation", "[", 
        RowBox[{"zoneA", ",", " ", 
         RowBox[{"MatrixExp", "[", 
          RowBox[{"t", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "gamma", ",", " ", "0"}], "}"}], ",", 
             " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", 
               RowBox[{"Log", "[", "k", "]"}], ",", " ", "0"}], "}"}], ",", 
             " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0", ",", " ", 
               RowBox[{"-", 
                RowBox[{"Log", "[", "k", "]"}]}]}], "}"}]}], "}"}]}], "]"}]}],
         "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"zoneB", " ", "=", " ", 
       RowBox[{"deformation", "[", 
        RowBox[{"zoneB", ",", " ", 
         RowBox[{"MatrixExp", "[", 
          RowBox[{"t", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "gamma", ",", " ", "0"}], "}"}], ",", 
             " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", 
               RowBox[{"Log", "[", "k", "]"}], ",", " ", "0"}], "}"}], ",", 
             " ", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0", ",", " ", 
               RowBox[{"-", 
                RowBox[{"Log", "[", "k", "]"}]}]}], "}"}]}], "}"}]}], "]"}]}],
         "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"curvesGraphic", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
        "blockA", ",", " ", "blockB", ",", " ", "zoneA", ",", " ", "zoneB"}], 
        "]"}], "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"velocity", ",", " ", "transpressionGraphicRC"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"velocity", "[", 
    RowBox[{"h0_", ",", " ", "gamma_", ",", " ", "k_"}], "]"}], " ", ":=", 
   "\n", "\t", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "x"}], "}"}], ",", "\n", "\t\t", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"h", ",", " ", "u1", ",", " ", "u2"}], "}"}], ",", "\n", 
       "\t\t\t", 
       RowBox[{
        RowBox[{"h", " ", "=", " ", 
         RowBox[{"h0", " ", 
          RowBox[{"k", "^", "t"}]}]}], ";", "\n", "\t\t\t", 
        RowBox[{"u1", " ", "=", " ", 
         RowBox[{"gamma", " ", "h"}]}], ";", "\n", "\t\t\t", 
        RowBox[{"u2", " ", "=", " ", 
         RowBox[{
          RowBox[{"Log", "[", "k", "]"}], " ", "h"}]}], ";", "\n", "\t\t\t", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"u1", " ", "/", " ", "h"}], " ", 
           RowBox[{"x", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ",", "\n", "\t\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", " ", "u2"}], ")"}], " ", "/", " ", 
             RowBox[{"(", 
              RowBox[{"2", " ", "h"}], ")"}]}], " ", 
            RowBox[{"x", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", " ", 
           RowBox[{
            RowBox[{"u2", " ", "/", " ", 
             RowBox[{"(", 
              RowBox[{"2", " ", 
               RowBox[{"h", "^", "3"}]}], ")"}]}], " ", 
            RowBox[{
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "3"}]}]}], ",", "\n", 
          "\t\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", " ", "u2"}], ")"}], " ", "/", " ", 
             RowBox[{"(", 
              RowBox[{"2", " ", 
               RowBox[{"h", "^", "3"}]}], ")"}]}], " ", 
            RowBox[{
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", "2"}], " ", 
            RowBox[{"x", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], " ", "-", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", " ", "u2"}], ")"}], " ", "/", " ", 
             RowBox[{"(", 
              RowBox[{"2", " ", "h"}], ")"}]}], " ", 
            RowBox[{"x", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}]}]}], "}"}]}]}], "]"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"transpressionGraphicRC", "[", 
    RowBox[{"h0_", ",", " ", "gamma_", ",", " ", "k_", ",", " ", "t_"}], 
    "]"}], " ", ":=", "\n", "\t", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "zoneA", ",", " ", "zoneB", ",", " ", "blockA", ",", " ", "blockB", ",",
        " ", "f", ",", " ", "disp"}], "}"}], ",", "\n", "\t\t", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Set", " ", "up", " ", "the", " ", "geometry", " ", "at", " ", "time", 
       " ", "0."}], " ", "*)"}], "\n", "\t\t", 
     RowBox[{
      RowBox[{"zoneA", " ", "=", " ", 
       RowBox[{"scaling", "[", 
        RowBox[{
         RowBox[{"zoneCurves", "[", 
          RowBox[{"4", ",", " ", "16"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"2", ",", " ", "h0", ",", " ", "2"}], "}"}]}], "]"}]}], ";",
       "\n", "\t\t", 
      RowBox[{"zoneB", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"zoneA", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", " ", "0", ",", " ", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"zoneA", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"zoneA", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", " ", 
           RowBox[{"-", "h0"}], ",", " ", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"blockA", " ", "=", " ", 
       RowBox[{"scaling", "[", 
        RowBox[{"cubeCurves", ",", " ", 
         RowBox[{"{", 
          RowBox[{"2", ",", " ", "1", ",", " ", "2"}], "}"}]}], "]"}]}], ";", 
      "\n", "\t\t", 
      RowBox[{"blockB", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"blockA", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", " ", "h0", ",", " ", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"blockA", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"blockA", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", " ", 
           RowBox[{
            RowBox[{"-", "3"}], "h0"}], ",", " ", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Compute", " ", "the", " ", "block", " ", "displacement", " ", "at", 
        " ", "time", " ", 
        RowBox[{"t", "."}]}], " ", "*)"}], "\n", "\t\t", 
      RowBox[{"f", " ", "=", " ", 
       RowBox[{"MatrixExp", "[", 
        RowBox[{"t", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "gamma", ",", " ", "0"}], "}"}], ",", " ", 
           
           RowBox[{"{", 
            RowBox[{"0", ",", " ", 
             RowBox[{"Log", "[", "k", "]"}], ",", " ", "0"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0", ",", " ", 
             RowBox[{"-", 
              RowBox[{"Log", "[", "k", "]"}]}]}], "}"}]}], "}"}]}], "]"}]}], 
      ";", "\n", "\t\t", 
      RowBox[{"disp", " ", "=", " ", 
       RowBox[{
        RowBox[{"f", ".", 
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "h0", ",", " ", "0"}], "}"}]}], " ", "-", 
        " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "h0", ",", " ", "0"}], "}"}]}]}], ";", "\n", 
      "\t\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Compute", " ", "the", " ", "geometry", " ", "at", " ", "time", " ", 
        RowBox[{"t", "."}]}], " ", "*)"}], "\n", "\t\t", 
      RowBox[{"blockA", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"blockA", ",", " ", 
         RowBox[{"-", "disp"}]}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"blockB", " ", "=", " ", 
       RowBox[{"translation", "[", 
        RowBox[{"blockB", ",", " ", "disp"}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"zoneA", " ", "=", " ", 
       RowBox[{"flow", "[", 
        RowBox[{"zoneA", ",", " ", 
         RowBox[{"velocity", "[", 
          RowBox[{"h0", ",", " ", "gamma", ",", " ", "k"}], "]"}], ",", " ", 
         "t"}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"zoneB", " ", "=", " ", 
       RowBox[{"flow", "[", 
        RowBox[{"zoneB", ",", " ", 
         RowBox[{"velocity", "[", 
          RowBox[{"h0", ",", " ", "gamma", ",", " ", "k"}], "]"}], ",", " ", 
         "t"}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"curvesGraphic", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
        "blockA", ",", " ", "blockB", ",", " ", "zoneA", ",", " ", "zoneB"}], 
        "]"}], "]"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.56915344977273*^9, 3.569153450877409*^9}, {
  3.569245330872466*^9, 3.569245333428319*^9}, {3.569245435579606*^9, 
  3.569245488011631*^9}, {3.731427224581306*^9, 3.731427308427389*^9}, {
  3.731427353195085*^9, 3.731427394279112*^9}, {3.731428220343533*^9, 
  3.7314282361611977`*^9}},ExpressionUUID->"9ad62e6b-f5dc-4a4d-a7b3-\
a9b553e2162c"],

Cell["\<\
Here is another 3D linear transformation. It is a combination of pure \
shearing and simple shearing. Deformable material is trapped between two \
strong, rigid blocks. The material is sheared in the x (red) direction and \
smushed in the y (green) direction. To compensate for the smushing, it \
extrudes in the z (blue) direction.\
\>", "Text",
 CellChangeTimes->{{3.731428132178913*^9, 3.731428152939988*^9}, {
  3.7314282423613358`*^9, 3.7314282441127977`*^9}, {3.7314283010311413`*^9, 
  3.731428308647522*^9}, {3.731428397589789*^9, 
  3.731428470571666*^9}},ExpressionUUID->"3d2fe62d-2b58-459f-be0a-\
464a458c6ae8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gamma", " ", "=", " ", "1.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logK", " ", "=", " ", 
   RowBox[{"-", "0.5"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"MatrixExp", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "gamma", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "logK", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", 
       RowBox[{"-", "logK"}]}], "}"}]}], "}"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"transpressionGraphicTF", "[", 
    RowBox[{"0.5", ",", " ", "1.0", ",", " ", 
     RowBox[{"Exp", "[", "logK", "]"}], ",", " ", "t"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.731427510768214*^9, 3.73142754618504*^9}, {
  3.731428162448865*^9, 3.731428217849421*^9}, {3.731428315563526*^9, 
  3.73142836892058*^9}},ExpressionUUID->"89ddefef-44f7-4244-93c8-\
48ac0358e1da"],

Cell["\<\
The preceding model is very simplistic. The following model is more realistic \
and more complicated. Intuitively, differing linear transformations act on \
differing parts of the rock, to produce a non-linear effect overall.\
\>", "Text",
 CellChangeTimes->{{3.731428479900236*^9, 3.731428539867497*^9}, {
  3.73142877772136*^9, 
  3.731428794080064*^9}},ExpressionUUID->"90012d26-0374-4e59-a0d2-\
3ed1b2a90c75"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gamma", " ", "=", " ", "1.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logK", " ", "=", " ", 
   RowBox[{"-", "0.5"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"transpressionGraphicRC", "[", 
    RowBox[{"0.5", ",", " ", "gamma", ",", " ", 
     RowBox[{"Exp", "[", "logK", "]"}], ",", " ", "t"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.569153575551813*^9, 3.5691535904837713`*^9}, {
   3.569153675301248*^9, 3.5691537104335947`*^9}, 3.5691537653068857`*^9, {
   3.73142741003918*^9, 3.731427422294722*^9}, 3.731427517358284*^9, {
   3.731428230349845*^9, 3.731428231943609*^9}, {3.731428545591795*^9, 
   3.731428562599853*^9}},ExpressionUUID->"fad9c124-0b37-444b-a148-\
b0cded410bb8"],

Cell["\<\
Arbitrarily complicated deformations can be built up by patching together \
linear transformations like this. The patching is governed by partial \
differential equations such as the Navier-Stokes equation. So there is always \
more math to learn. But linear algebra is a crucial tool in all of it.\
\>", "Text",
 CellChangeTimes->{{3.7314287969139423`*^9, 
  3.7314288592438717`*^9}},ExpressionUUID->"3c216a3f-b1a0-4307-a0c7-\
63fbb75ce5e2"]
}, Open  ]]
},
WindowSize->{1037, 755},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"11.2 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 181, 3, 35, "Text",ExpressionUUID->"110428d9-9d44-43c0-8541-740ba33aef00"],
Cell[CellGroupData[{
Cell[764, 27, 157, 3, 67, "Section",ExpressionUUID->"4a6ded8e-c170-428e-ad00-71feadc4ac30"],
Cell[924, 32, 889, 16, 173, "Text",ExpressionUUID->"bcbdea87-1a3e-419a-8adb-3285c878fe1c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1850, 53, 158, 3, 67, "Section",ExpressionUUID->"0a6e9ec8-c917-4590-8734-7f19f36a8c03"],
Cell[2011, 58, 351, 7, 35, "Text",ExpressionUUID->"d1b0d43d-ddb4-44c7-8ea6-383060a6d197"],
Cell[2365, 67, 16535, 458, 1018, "Input",ExpressionUUID->"5c427fc6-9b24-4ccb-a382-3de6aab81682"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18937, 530, 153, 3, 67, "Section",ExpressionUUID->"618be81e-2e1d-4c69-9542-8895c509a573"],
Cell[19093, 535, 650, 11, 81, "Text",ExpressionUUID->"3c8bd183-6627-4c4e-9caf-ece6f5e777e7"],
Cell[19746, 548, 1051, 25, 94, "Input",ExpressionUUID->"ca00027d-27bd-4f01-99ec-4f53ef1f926b"],
Cell[20800, 575, 633, 11, 58, "Text",ExpressionUUID->"578e0f6e-2f49-440b-a655-521fda441a9f"],
Cell[21436, 588, 948, 24, 94, "Input",ExpressionUUID->"b5ce6e03-aae2-437c-88fd-1b47cd4796d9"],
Cell[22387, 614, 560, 10, 58, "Text",ExpressionUUID->"afcc0997-b1b3-4cea-98d8-bc44f3799d72"],
Cell[22950, 626, 962, 25, 94, "Input",ExpressionUUID->"00300c81-3e6e-43be-839f-5a3664d2a8b7"],
Cell[23915, 653, 810, 13, 81, "Text",ExpressionUUID->"7fc55463-b935-4f26-aec3-0ba53d41a278"],
Cell[24728, 668, 2418, 61, 136, "Input",ExpressionUUID->"604ea736-7ca2-4a22-a370-22bd56bc696e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27183, 734, 217, 4, 67, "Section",ExpressionUUID->"2b02ec06-cc8c-49f5-80a7-7d9f4c29b31d"],
Cell[27403, 740, 394, 7, 58, "Text",ExpressionUUID->"6f45deab-f065-47cd-9dbe-8a7f19794cb6"],
Cell[27800, 749, 27435, 710, 2152, "Input",ExpressionUUID->"9ad62e6b-f5dc-4a4d-a7b3-a9b553e2162c"],
Cell[55238, 1461, 632, 11, 81, "Text",ExpressionUUID->"3d2fe62d-2b58-459f-be0a-464a458c6ae8"],
Cell[55873, 1474, 1141, 28, 94, "Input",ExpressionUUID->"89ddefef-44f7-4244-93c8-48ac0358e1da"],
Cell[57017, 1504, 423, 8, 58, "Text",ExpressionUUID->"90012d26-0374-4e59-a0d2-3ed1b2a90c75"],
Cell[57443, 1514, 872, 18, 73, "Input",ExpressionUUID->"fad9c124-0b37-444b-a148-b0cded410bb8"],
Cell[58318, 1534, 452, 8, 58, "Text",ExpressionUUID->"3c216a3f-b1a0-4307-a0c7-63fbb75ce5e2"]
}, Open  ]]
}
]
*)

